summaryrefslogtreecommitdiffstats
path: root/kexi/widget/tableview/kexitableedit.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kexi/widget/tableview/kexitableedit.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/widget/tableview/kexitableedit.h')
-rw-r--r--kexi/widget/tableview/kexitableedit.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kexi/widget/tableview/kexitableedit.h b/kexi/widget/tableview/kexitableedit.h
index ef618178..4630757c 100644
--- a/kexi/widget/tableview/kexitableedit.h
+++ b/kexi/widget/tableview/kexitableedit.h
@@ -42,7 +42,7 @@ class KEXIDATATABLE_EXPORT KexiTableEdit : public TQWidget, public KexiDataItemI
TQ_OBJECT
public:
- KexiTableEdit(KexiTableViewColumn &column, TQWidget* tqparent = 0);
+ KexiTableEdit(KexiTableViewColumn &column, TQWidget* parent = 0);
virtual ~KexiTableEdit();
@@ -184,7 +184,7 @@ class KEXIDATATABLE_EXPORT KexiTableEdit : public TQWidget, public KexiDataItemI
for the editor, its events will be filtered, it will be resized when neede, and so on. */
void setViewWidget(TQWidget *v);
/*! Moves child widget within the viewport if the tqparent is scrollview (otherwise does nothing).
Use this for child widgets that are outside of this editor widget, instead of calling TQWidget::move(). */
void moveChild( TQWidget * child, int x, int y );
@@ -195,7 +195,7 @@ class KEXIDATATABLE_EXPORT KexiTableEdit : public TQWidget, public KexiDataItemI
KexiTableViewColumn *m_column;
int m_leftMargin;
int m_rightMargin, m_rightMarginWhenFocused;
- TQScrollView* m_scrollView; //!< may be 0 if the tqparent is not a scrollview
+ TQScrollView* m_scrollView; //!< may be 0 if the parent is not a scrollview
bool m_usesSelectedTextColor : 1; //!< set in ctor, @see usesSelectedTextColor()
private:
@@ -211,7 +211,7 @@ class KEXIDATATABLE_EXPORT KexiTableEdit : public TQWidget, public KexiDataItemI
virtual ~factoryclassname(); \
\
protected: \
- virtual KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* tqparent = 0); \
+ virtual KexiTableEdit* createEditor(KexiTableViewColumn &column, TQWidget* parent = 0); \
};
//! Implementation of cell editor factory
@@ -226,9 +226,9 @@ factoryclassname::~factoryclassname() \
{} \
\
KexiTableEdit* factoryclassname::createEditor( \
- KexiTableViewColumn &column, TQWidget* tqparent) \
+ KexiTableViewColumn &column, TQWidget* parent) \
{ \
- return new itemclassname(column, tqparent); \
+ return new itemclassname(column, parent); \
}
#endif
@@ -184,7 +184,7 @@ class KEXIDATATABLE_EXPORT KexiTableEdit : public TQWidget, public KexiDataItemI
for the editor, its events will be filtered, it will be resized when neede, and so on. */
void setViewWidget(TQWidget *v);
- /*! Moves child widget within the viewport if the tqparent is scrollview (otherwise does nothing).
+ /*! Moves child widget within the viewport if the parent is scrollview (otherwise does nothing).
Use this for child widgets that are outside of this editor widget, instead of calling TQWidget::move(). */
void moveChild( TQWidget * child, int x, int y );